/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsecurityorigin.sip"
#include <qwebsecurityorigin.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"

#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebdatabase.sip"
#include <qwebdatabase.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSecurityOrigin.cpp"


PyDoc_STRVAR(doc_QWebSecurityOrigin_allOrigins, "allOrigins() -> list[QWebSecurityOrigin]");

extern "C" {static PyObject *meth_QWebSecurityOrigin_allOrigins(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_allOrigins(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QWebSecurityOrigin>*sipRes;

            sipRes = new QList< ::QWebSecurityOrigin>(::QWebSecurityOrigin::allOrigins());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebSecurityOrigin, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_allOrigins, doc_QWebSecurityOrigin_allOrigins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_scheme, "scheme(self) -> str");

extern "C" {static PyObject *meth_QWebSecurityOrigin_scheme(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_scheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->scheme());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_scheme, doc_QWebSecurityOrigin_scheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_host, "host(self) -> str");

extern "C" {static PyObject *meth_QWebSecurityOrigin_host(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_host(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->host());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_host, doc_QWebSecurityOrigin_host);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_port, "port(self) -> int");

extern "C" {static PyObject *meth_QWebSecurityOrigin_port(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_port(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->port();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_port, doc_QWebSecurityOrigin_port);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_databaseUsage, "databaseUsage(self) -> int");

extern "C" {static PyObject *meth_QWebSecurityOrigin_databaseUsage(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_databaseUsage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->databaseUsage();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_databaseUsage, doc_QWebSecurityOrigin_databaseUsage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_databaseQuota, "databaseQuota(self) -> int");

extern "C" {static PyObject *meth_QWebSecurityOrigin_databaseQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_databaseQuota(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->databaseQuota();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_databaseQuota, doc_QWebSecurityOrigin_databaseQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_setDatabaseQuota, "setDatabaseQuota(self, quota: int)");

extern "C" {static PyObject *meth_QWebSecurityOrigin_setDatabaseQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_setDatabaseQuota(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp, &a0))
        {
            sipCpp->setDatabaseQuota(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_setDatabaseQuota, doc_QWebSecurityOrigin_setDatabaseQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_databases, "databases(self) -> list[QWebDatabase]");

extern "C" {static PyObject *meth_QWebSecurityOrigin_databases(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_databases(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp))
        {
            QList< ::QWebDatabase>*sipRes;

            sipRes = new QList< ::QWebDatabase>(sipCpp->databases());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebDatabase, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_databases, doc_QWebSecurityOrigin_databases);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_addLocalScheme, "addLocalScheme(scheme: Optional[str])");

extern "C" {static PyObject *meth_QWebSecurityOrigin_addLocalScheme(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_addLocalScheme(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSecurityOrigin::addLocalScheme(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_addLocalScheme, doc_QWebSecurityOrigin_addLocalScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_removeLocalScheme, "removeLocalScheme(scheme: Optional[str])");

extern "C" {static PyObject *meth_QWebSecurityOrigin_removeLocalScheme(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_removeLocalScheme(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSecurityOrigin::removeLocalScheme(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_removeLocalScheme, doc_QWebSecurityOrigin_removeLocalScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_localSchemes, "localSchemes() -> list[str]");

extern "C" {static PyObject *meth_QWebSecurityOrigin_localSchemes(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_localSchemes(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QWebSecurityOrigin::localSchemes());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_localSchemes, doc_QWebSecurityOrigin_localSchemes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_setApplicationCacheQuota, "setApplicationCacheQuota(self, quota: int)");

extern "C" {static PyObject *meth_QWebSecurityOrigin_setApplicationCacheQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_setApplicationCacheQuota(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp, &a0))
        {
            sipCpp->setApplicationCacheQuota(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_setApplicationCacheQuota, doc_QWebSecurityOrigin_setApplicationCacheQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_addAccessWhitelistEntry, "addAccessWhitelistEntry(self, scheme: Optional[str], host: Optional[str], subdomainSetting: QWebSecurityOrigin.SubdomainSetting)");

extern "C" {static PyObject *meth_QWebSecurityOrigin_addAccessWhitelistEntry(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_addAccessWhitelistEntry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebSecurityOrigin::SubdomainSetting a2;
        ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1E", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QWebSecurityOrigin_SubdomainSetting, &a2))
        {
            sipCpp->addAccessWhitelistEntry(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_addAccessWhitelistEntry, doc_QWebSecurityOrigin_addAccessWhitelistEntry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSecurityOrigin_removeAccessWhitelistEntry, "removeAccessWhitelistEntry(self, scheme: Optional[str], host: Optional[str], subdomainSetting: QWebSecurityOrigin.SubdomainSetting)");

extern "C" {static PyObject *meth_QWebSecurityOrigin_removeAccessWhitelistEntry(PyObject *, PyObject *);}
static PyObject *meth_QWebSecurityOrigin_removeAccessWhitelistEntry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebSecurityOrigin::SubdomainSetting a2;
        ::QWebSecurityOrigin *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1E", &sipSelf, sipType_QWebSecurityOrigin, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QWebSecurityOrigin_SubdomainSetting, &a2))
        {
            sipCpp->removeAccessWhitelistEntry(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSecurityOrigin, sipName_removeAccessWhitelistEntry, doc_QWebSecurityOrigin_removeAccessWhitelistEntry);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebSecurityOrigin(void *, int);}
static void release_QWebSecurityOrigin(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebSecurityOrigin *>(sipCppV);
}


extern "C" {static void assign_QWebSecurityOrigin(void *, Py_ssize_t, void *);}
static void assign_QWebSecurityOrigin(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebSecurityOrigin *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebSecurityOrigin *>(sipSrc);
}


extern "C" {static void *copy_QWebSecurityOrigin(const void *, Py_ssize_t);}
static void *copy_QWebSecurityOrigin(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebSecurityOrigin(reinterpret_cast<const ::QWebSecurityOrigin *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebSecurityOrigin(sipSimpleWrapper *);}
static void dealloc_QWebSecurityOrigin(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebSecurityOrigin(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebSecurityOrigin(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebSecurityOrigin(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebSecurityOrigin *sipCpp = SIP_NULLPTR;

    {
        const ::QUrl* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QUrl, &a0))
        {
            sipCpp = new ::QWebSecurityOrigin(*a0);

            return sipCpp;
        }
    }

    {
        const ::QWebSecurityOrigin* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebSecurityOrigin, &a0))
        {
            sipCpp = new ::QWebSecurityOrigin(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QWebSecurityOrigin[] = {
    {sipName_addAccessWhitelistEntry, meth_QWebSecurityOrigin_addAccessWhitelistEntry, METH_VARARGS, doc_QWebSecurityOrigin_addAccessWhitelistEntry},
    {sipName_addLocalScheme, meth_QWebSecurityOrigin_addLocalScheme, METH_VARARGS, doc_QWebSecurityOrigin_addLocalScheme},
    {sipName_allOrigins, meth_QWebSecurityOrigin_allOrigins, METH_VARARGS, doc_QWebSecurityOrigin_allOrigins},
    {sipName_databaseQuota, meth_QWebSecurityOrigin_databaseQuota, METH_VARARGS, doc_QWebSecurityOrigin_databaseQuota},
    {sipName_databaseUsage, meth_QWebSecurityOrigin_databaseUsage, METH_VARARGS, doc_QWebSecurityOrigin_databaseUsage},
    {sipName_databases, meth_QWebSecurityOrigin_databases, METH_VARARGS, doc_QWebSecurityOrigin_databases},
    {sipName_host, meth_QWebSecurityOrigin_host, METH_VARARGS, doc_QWebSecurityOrigin_host},
    {sipName_localSchemes, meth_QWebSecurityOrigin_localSchemes, METH_VARARGS, doc_QWebSecurityOrigin_localSchemes},
    {sipName_port, meth_QWebSecurityOrigin_port, METH_VARARGS, doc_QWebSecurityOrigin_port},
    {sipName_removeAccessWhitelistEntry, meth_QWebSecurityOrigin_removeAccessWhitelistEntry, METH_VARARGS, doc_QWebSecurityOrigin_removeAccessWhitelistEntry},
    {sipName_removeLocalScheme, meth_QWebSecurityOrigin_removeLocalScheme, METH_VARARGS, doc_QWebSecurityOrigin_removeLocalScheme},
    {sipName_scheme, meth_QWebSecurityOrigin_scheme, METH_VARARGS, doc_QWebSecurityOrigin_scheme},
    {sipName_setApplicationCacheQuota, meth_QWebSecurityOrigin_setApplicationCacheQuota, METH_VARARGS, doc_QWebSecurityOrigin_setApplicationCacheQuota},
    {sipName_setDatabaseQuota, meth_QWebSecurityOrigin_setDatabaseQuota, METH_VARARGS, doc_QWebSecurityOrigin_setDatabaseQuota}
};

static sipEnumMemberDef enummembers_QWebSecurityOrigin[] = {
    {sipName_AllowSubdomains, static_cast<int>(::QWebSecurityOrigin::AllowSubdomains), 21},
    {sipName_DisallowSubdomains, static_cast<int>(::QWebSecurityOrigin::DisallowSubdomains), 21},
};

PyDoc_STRVAR(doc_QWebSecurityOrigin, "\1QWebSecurityOrigin(url: QUrl)\n"
"QWebSecurityOrigin(other: QWebSecurityOrigin)");


static pyqt5ClassPluginDef plugin_QWebSecurityOrigin = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebSecurityOrigin = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebSecurityOrigin,
        SIP_NULLPTR,
        &plugin_QWebSecurityOrigin,
    },
    {
        sipNameNr_QWebSecurityOrigin,
        {0, 0, 1},
        14, methods_QWebSecurityOrigin,
        2, enummembers_QWebSecurityOrigin,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebSecurityOrigin,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QWebSecurityOrigin,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebSecurityOrigin,
    assign_QWebSecurityOrigin,
    SIP_NULLPTR,
    copy_QWebSecurityOrigin,
    release_QWebSecurityOrigin,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QWebSecurityOrigin),
};
